@@ -8,14 +8,9 @@ import matplotlib.pyplot as plt
 from scipy.signal import find_peaks
 from scipy.interpolate import interp1d
 
-"""
-TODO
-    Consider removing ShiftDataFrame - I don't think this us used anymore
-"""
 
 
-
-def GetCycleSubVector(VectorX, VectorY, Index1, Index2, Nsample):
+def getCycleSubVector(VectorX, VectorY, Index1, Index2, Nsample):
     """
       
     
@@ -60,13 +55,49 @@ def GetCycleSubVector(VectorX, VectorY, Index1, Index2, Nsample):
     ySample = InterpFunction(xSample)
           
     return xSample,ySample
-        
+
+
+def getMaxIndicies(VectorX, peakDist = 2, peakWidth = None, 
+                     peakProminence = None, **kwargs):
+    MaxIndexes,_ = find_peaks(VectorX, height = (None, None), distance = peakDist, 
+                            width = peakWidth, prominence = peakProminence, **kwargs)
+
+    Nindex = len(MaxIndexes) + 2
+    Indexes = np.zeros(Nindex, dtype = int)
+    Indexes[0] = 0
+    Indexes[-1] = len(VectorX) - 1
     
-def GetCycleIndicies(VectorX, peakDist = 2, peakWidth = None, 
-                     peakProminence = None, VectorY = np.array([]), CreatePlot = False):
+    Indexes[1:-1] = MaxIndexes
+
+    return Indexes
+
+
+
+
+def _findOrder(L1, L2, MinIndexes, MaxIndexes):
+    # We check the order, starting with the minimum number of possibilities
+    # if there are no minimus, order doesn't matter
+    # If the first index is a minimum, order = 1, otherwise order = 2
+    if L1 == 0 and L2 == 0: # Edge case 1: Curve is monotonic - order doesn't matter
+        order = 1
+    elif L1 == 0: # Edge case 2: There are no intermediate min points and one intermediate max
+        order = 2
+    elif L2 == 0: # Edge case 3: There are no intermediate maxi points and one intermediate min
+        order = 1
+    elif MinIndexes[0] < MaxIndexes[0]: 
+        order = 1
+    else:
+        order = 2
+    return order
+
+
+
+def getCycleIndicies(VectorX, peakDist = 2, peakWidth = None, 
+                     peakProminence = None, **kwargs):
     """
     This function finds the index where there is areversal in the XY data. 
     You may need to adjust the find peaks factor to get satisfactory results.
+    Built on the scipy find peaks funciton
     
 
     Parameters
@@ -77,8 +108,19 @@ def GetCycleIndicies(VectorX, peakDist = 2, peakWidth = None,
         Input Y Vector. This is only used if we want to plot the values.
     CreatePlot : Boolean
         This switch specifies whether or not to display the output.plot
-    peakDist : TYPE, optional
-        The sampling distance used to find peaks. The default is 2.
+    peakDist : int, optional
+        Required minimal horizontal distance (>= 1) in samples between
+        neighbouring peaks. Smaller peaks are removed first until the condition
+        is fulfilled for all remaining peaks.
+        The default is 2.
+    peakWidth : int, optional
+        The approximate width in number of samples of the peak at half it's prominence.
+        Peaks that occur very abruptly have a small width, while those that occur
+        gradually have a big width.
+    peakProminence : number, optional
+        Used to filter out peaks that aren't sufficently high. Prominence is 
+        the desired difference in height between peaks and their neighbouring peaks. 
+        The default is None, which results in no filtering.
 
     Returns
     -------
@@ -100,21 +142,7 @@ def GetCycleIndicies(VectorX, peakDist = 2, peakWidth = None,
     # the max and min values in an array of indexes
     Nindex = len(MaxIndexes) + len(MinIndexes) + 2
     Indexes = np.zeros(Nindex, dtype = int)
-    
-    
-    # # If no value was found, we assume monotonic
-    # if not MaxIndex: 
-    #     print('No local peaks were found, assuming x data is monotonic.')
-    #     Nindex = 2
-    #     MinIndex = [0]
-    #     MaxIndex = [len(VectorX) - 1]
-    #     Indexes = np.zeros(Nindex, dtype = int)
-    
-    # plt.plot(VectorX)
-    # plt.plot(MaxIndexes,VectorX[MaxIndexes], 'x')
-    # plt.plot(MinIndexes,VectorX[MinIndexes], '+')
-    # plt.show()
-    
+       
     # Define first and last point
     Indexes[0] = 0
     Indexes[-1] = len(VectorX) - 1
@@ -125,23 +153,10 @@ def GetCycleIndicies(VectorX, peakDist = 2, peakWidth = None,
     
     if abs(L1 - L2) > 1:
         raise Exception('There are', L1, 'minimums which is more than one than ', L2, ' maximums. There are likely repeated peaks.')
-        
     
-    # We check the order, starting with the minimum number of possibilities
-    # if there are no minimus, order doesn't matter
-    # If the first index is a minimum, order = 1, otherwise order = 2
-    if L1 == 0 and L2 == 0: # Edge case 1: Curve is monotonic - order doesn't matter
-        order = 1
-    elif L1 == 0: # Edge case 2: There are no intermediate min points and one intermediate max
-        order = 2
-    elif L2 == 0: # Edge case 3: There are no intermediate maxi points and one intermediate min
-        order = 1
-    elif MinIndexes[0] < MaxIndexes[0]: 
-        order = 1
-    else:
-        order = 2
+    # 1 means min first, 2 means max first
+    order = _findOrder(L1, L2, MinIndexes, MaxIndexes)
     
-    # We assign the order. We also check if there are any entries to assign.
     if order == 1:
         Indexes[1:-1:2] = MinIndexes
         if L2 !=0:
@@ -149,37 +164,13 @@ def GetCycleIndicies(VectorX, peakDist = 2, peakWidth = None,
     else:
         Indexes[1:-1:2] = MaxIndexes
         if L1 !=0:
-            Indexes[2:-1:2] = MinIndexes
-    
-    # make a picture if it is true
-    if CreatePlot == True:
-        if VectorY.size == 0:
-            VectorY = VectorX
-        
-        MaxValueXValue = VectorX[Indexes]
-        MaxValueYValue = VectorY[Indexes]        
-
-        fig = plt.subplots()
-        line  = plt.plot(Indexes,MaxValueYValue,'x')
-        # line  = plt.plot(MaxIndex,MaxValueYpos,'x')
-        # line  = plt.plot(MinIndex,MaxValueYneg,'x')
-        
-        line2  = plt.plot(VectorY[:])
-        plt.title('Peak Indexes')
-        plt.show()
-        
-        
-        fig = plt.subplots()        
-        line2  = plt.plot(VectorX,VectorY)
-        line  = plt.plot(MaxValueXValue,MaxValueYValue,'x')
-        plt.title('Peak Index x values')
-        plt.show()
-    
+            Indexes[2:-1:2] = MinIndexes      
+ 
     
     return Indexes
 
 
-def LinearInterpolation(x1, x2, y1, y2, x):
+def linearInterpolation(x1, x2, y1, y2, x):
     """
     A default linear interpolation functions for the value x between two points
     p1 = (x1,y1) and p2 = (x2,y2). 
@@ -209,7 +200,7 @@ def LinearInterpolation(x1, x2, y1, y2, x):
 
 
 
-def SampleData(ExperimentX, ExperimentY, AnalysisX, AnalysisY, Nsample = 10, 
+def sampleData(ExperimentX, ExperimentY, AnalysisX, AnalysisY, Nsample = 10, 
                peakDist = 2, peakwidth = None, Norm = None):
     """
         
@@ -245,8 +236,8 @@ def SampleData(ExperimentX, ExperimentY, AnalysisX, AnalysisY, Nsample = 10,
        
     # We get the indicies where the reversal happens.
     
-    ExperimentIndicies = GetCycleIndicies(ExperimentX, Nsample, peakDist, peakwidth, ExperimentY)
-    AnalysisIndicies = GetCycleIndicies(AnalysisX, Nsample, peakDist, peakwidth, AnalysisY)
+    ExperimentIndicies = getCycleIndicies(ExperimentX, Nsample, peakDist, peakwidth, ExperimentY)
+    AnalysisIndicies = getCycleIndicies(AnalysisX, Nsample, peakDist, peakwidth, AnalysisY)
     
     # We check that both curves have the same number of indicies
     NIndex = len(ExperimentIndicies) - 1
@@ -266,8 +257,8 @@ def SampleData(ExperimentX, ExperimentY, AnalysisX, AnalysisY, Nsample = 10,
         Ay = np.zeros(NIndex)
         
         # We get the subvector values between the indicies
-        [Ex,Ey] = GetCycleSubVector(ExperimentX , ExperimentY, ExperimentIndicies[ii], ExperimentIndicies[ii+1], Nsample)
-        [Ax,Ay] = GetCycleSubVector(AnalysisX , AnalysisY, AnalysisIndicies[ii], AnalysisIndicies[ii+1], Nsample)
+        [Ex,Ey] = getCycleSubVector(ExperimentX , ExperimentY, ExperimentIndicies[ii], ExperimentIndicies[ii+1], Nsample)
+        [Ax,Ay] = getCycleSubVector(AnalysisX , AnalysisY, AnalysisIndicies[ii], AnalysisIndicies[ii+1], Nsample)
         
         # We sample each point on the curve using the difference between the
         # two points
@@ -281,7 +272,7 @@ def SampleData(ExperimentX, ExperimentY, AnalysisX, AnalysisY, Nsample = 10,
     return Rnet
 
 
-def SampleMonotonicData(ExperimentX, ExperimentY, AnalysisX, AnalysisY,
+def sampleMonotonicData(ExperimentX, ExperimentY, AnalysisX, AnalysisY,
                         Nsample = 10, Norm = None):
     """
     This functions works the same way as the cyclic data function
@@ -318,8 +309,8 @@ def SampleMonotonicData(ExperimentX, ExperimentY, AnalysisX, AnalysisY,
         Ay = np.zeros(Nsample)
         
         
-        [Ex,Ey] = GetCycleSubVector(ExperimentX , ExperimentY, 0, Nindex, Nsample)
-        [Ax,Ay] = GetCycleSubVector(AnalysisX , AnalysisY, 0, Nindex, Nsample)
+        [Ex,Ey] = getCycleSubVector(ExperimentX , ExperimentY, 0, Nindex, Nsample)
+        [Ax,Ay] = getCycleSubVector(AnalysisX , AnalysisY, 0, Nindex, Nsample)
         
         R[ii] = np.sum(((Ey-Ay)**2 + (Ex-Ax)**2)**0.5)
         if Norm == None:
@@ -339,7 +330,7 @@ def SampleMonotonicData(ExperimentX, ExperimentY, AnalysisX, AnalysisY,
 # =============================================================================
 
 
-def ShiftDataFrame1(Samplex, Sampley, Targetx):
+def shiftDataFrame1(Samplex, Sampley, Targetx):
     """
     
     SciPy's ID interpolate baseically does what this does, it probably makes
@@ -434,9 +425,14 @@ def ShiftDataFrame1(Samplex, Sampley, Targetx):
                
         
         # Interpolate
-        Targety[ii] = LinearInterpolation(x1,x2,y1,y2,x)
+        Targety[ii] = linearInterpolation(x1,x2,y1,y2,x)
         
         ii+=1
         
     return Targety
 
+
+"""
+TODO
+    Consider removing ShiftDataFrame - I don't think this us used anymore
+"""
